.. _swh-core-cli:

Command-line interface
======================

Shared command-line interface
-----------------------------

.. click:: swh.core.cli:swh
  :prog: swh
  :show-nested:

Database initialization utilities
---------------------------------

.. click:: swh.core.cli.db:init
  :prog: swh db init
  :show-nested:

.. click:: swh.core.cli.db:db_init
  :prog: swh db-init
  :show-nested:
